@@ -130,9 +130,7 @@ osinfo_devicelink_class_init (OsinfoDeviceLinkClass *klass)
                                 OSINFO_TYPE_DEVICE,
                                 G_PARAM_CONSTRUCT_ONLY |
                                 G_PARAM_READWRITE |
-                                G_PARAM_STATIC_NAME |
-                                G_PARAM_STATIC_NICK |
-                                G_PARAM_STATIC_BLURB);
+                                G_PARAM_STATIC_STRINGS);
     g_object_class_install_property(g_klass,
                                     PROP_TARGET,
                                     pspec);
@@ -154,7 +152,7 @@ osinfo_devicelink_init (OsinfoDeviceLink *devlink)
  * osinfo_devicelink_new:
  * @target: the target device
  *
- * Construct a new link to a #OsinfoDevice. The unique ID
+ * Construct a new link for an #OsinfoDevice. The unique ID
  * of the link is set to match the ID of the target device.
  *
  * Returns: (transfer full): the new device link
