@@ -38,19 +38,20 @@ G_DEFINE_TYPE (OsinfoInstallScript, osinfo_install_script, OSINFO_TYPE_ENTITY);
 
 /**
  * SECTION:osinfo_install_script
- * @short_description: OS install scripturation
- * @see_also: #OsinfoInstallScript
+ * @short_description: OS install script generation
+ * @see_also: #OsinfoInstallConfig
  *
- * #OsinfoInstallScript is an object for representing OS
- * install scripturation data. It is used to generate an
- * automated installation script
+ * #OsinfoInstallScript is an object used to generate an
+ * automated installation script for an OS. The OS
+ * configuration data (language, keyboard, timezone, ...)
+ * comes from an #OsinfoInstallConfig object.
  */
 
 struct _OsinfoInstallScriptPrivate
 {
     gchar *output_prefix;
     gchar *output_filename;
-    GList *config_param_list;
+    OsinfoInstallConfigParamList *config_params;
     OsinfoAvatarFormat *avatar;
 };
 
@@ -164,8 +165,11 @@ osinfo_install_script_finalize (GObject *object)
     OsinfoInstallScript *script = OSINFO_INSTALL_SCRIPT (object);
     g_free(script->priv->output_prefix);
     g_free(script->priv->output_filename);
-    g_list_free_full(script->priv->config_param_list, g_object_unref);
-    if (script->priv->avatar != NULL)
+
+    if (script->priv->config_params)
+        g_object_unref(script->priv->config_params);
+
+    if (script->priv->avatar)
         g_object_unref(script->priv->avatar);
 
     /* Chain up to the parent class */
@@ -258,35 +262,23 @@ void osinfo_install_script_add_config_param(OsinfoInstallScript *script, OsinfoI
     g_return_if_fail(OSINFO_IS_INSTALL_SCRIPT(script));
     g_return_if_fail(OSINFO_IS_INSTALL_CONFIG_PARAM(param));
 
-    script->priv->config_param_list =
-        g_list_prepend(script->priv->config_param_list, param);
+    osinfo_list_add(OSINFO_LIST(script->priv->config_params),
+                    OSINFO_ENTITY(param));
 }
 
 gboolean osinfo_install_script_has_config_param(const OsinfoInstallScript *script, const OsinfoInstallConfigParam *config_param)
 {
-    GList *l;
-
-    for (l = script->priv->config_param_list; l != NULL; l = l->next) {
-        OsinfoInstallConfigParam *tmp = l->data;
-
-        if (g_strcmp0(osinfo_install_config_param_get_name(tmp),
-                      osinfo_install_config_param_get_name(config_param)) == 0)
-            return TRUE;
-    }
-    return FALSE;
+    /* NB: this code assumes that the 'id' and 'name' entity properties
+     * are the same
+     */
+    const char *name = osinfo_install_config_param_get_name(config_param);
+    return osinfo_install_script_has_config_param_name(script, name);
 }
 
 gboolean osinfo_install_script_has_config_param_name(const OsinfoInstallScript *script, const gchar *name)
 {
-    GList *l;
-
-    for (l = script->priv->config_param_list; l != NULL; l = l->next) {
-        OsinfoInstallConfigParam *tmp = l->data;
-
-        if (g_strcmp0(osinfo_install_config_param_get_name(tmp), name) == 0)
-            return TRUE;
-    }
-    return FALSE;
+    OsinfoList *l = OSINFO_LIST(script->priv->config_params);
+    return (osinfo_list_find_by_id(l, name) != NULL);
 }
 
 /**
@@ -300,7 +292,20 @@ gboolean osinfo_install_script_has_config_param_name(const OsinfoInstallScript *
  */
 GList *osinfo_install_script_get_config_param_list(const OsinfoInstallScript *script)
 {
-    return g_list_copy(script->priv->config_param_list);
+    return osinfo_list_get_elements(OSINFO_LIST(script->priv->config_params));
+}
+
+/**
+ * osinfo_install_script_get_config_params:
+ *
+ * Get the list of valid config parameters for @script.
+ *
+ * Returns: (transfer none): the list of valid #OsinfoInstallConfigParam
+ * parameters.
+ */
+OsinfoInstallConfigParamList *osinfo_install_script_get_config_params(const OsinfoInstallScript *script)
+{
+    return script->priv->config_params;
 }
 
 /**
@@ -317,16 +322,16 @@ OsinfoInstallConfigParam *
 osinfo_install_script_get_config_param(const OsinfoInstallScript *script,
                                        const gchar *name)
 {
-    GList *l;
+    /* NB: this code assumes that the 'id' and 'name' entity properties
+     * are the same
+     */
+    OsinfoInstallConfigParam *param;
+    OsinfoList *l = OSINFO_LIST(script->priv->config_params);
+    param = OSINFO_INSTALL_CONFIG_PARAM(osinfo_list_find_by_id(l, name));
+    if (param == NULL)
+        return NULL;
 
-    for (l = script->priv->config_param_list; l != NULL; l = l->next) {
-        OsinfoInstallConfigParam *tmp = l->data;
-
-        if (g_strcmp0(osinfo_install_config_param_get_name(tmp), name) == 0)
-            return g_object_ref(tmp);
-    }
-
-    return NULL;
+    return g_object_ref(G_OBJECT(param));
 }
 
 static void
@@ -335,7 +340,7 @@ osinfo_install_script_init (OsinfoInstallScript *list)
     OsinfoInstallScriptPrivate *priv;
     list->priv = priv = OSINFO_INSTALL_SCRIPT_GET_PRIVATE(list);
 
-    list->priv->config_param_list = NULL;
+    list->priv->config_params = osinfo_install_config_paramlist_new();
 }
 
 
@@ -507,7 +512,7 @@ osinfo_install_script_set_avatar_format(OsinfoInstallScript *script,
 }
 
 /**
- * osinfo_install_script_get_avatar_format
+ * osinfo_install_script_get_avatar_format:
  * @script: the install script
  *
  * Some install scripts have restrictions on the format of the user avatar. Use
@@ -598,10 +603,62 @@ static xsltStylesheetPtr osinfo_install_script_load_template(const gchar *uri,
     return xslt;
 }
 
-static xmlNodePtr osinfo_install_script_generate_entity_config(OsinfoInstallConfig *config,
-                                                               OsinfoEntity *entity,
-                                                               const gchar *name,
-                                                               GError **error)
+
+static OsinfoDatamap *
+osinfo_install_script_get_param_datamap(OsinfoInstallScript *script,
+                                        const gchar *param_name)
+{
+    OsinfoEntity *entity;
+    OsinfoInstallConfigParam *param;
+
+    if (!script->priv->config_params)
+        return NULL;
+
+    entity = osinfo_list_find_by_id(OSINFO_LIST(script->priv->config_params),
+                                    param_name);
+    if (entity == NULL) {
+        g_debug("%s is not a known parameter for this config", param_name);
+        return NULL;
+    }
+
+    param = OSINFO_INSTALL_CONFIG_PARAM(entity);
+    return osinfo_install_config_param_get_value_map(param);
+}
+
+
+static GList *
+osinfo_install_script_get_param_value_list(OsinfoInstallScript *script,
+                                           OsinfoInstallConfig *config,
+                                           const gchar *key)
+{
+    GList *values;
+    GList *it;
+    OsinfoDatamap *map;
+
+    values = osinfo_entity_get_param_value_list(OSINFO_ENTITY(config), key);
+    if (values == NULL)
+        return NULL;
+
+    map = osinfo_install_script_get_param_datamap(script, key);
+    if (map != NULL) {
+        for (it = values; it != NULL; it = it->next) {
+            const char *transformed_value;
+            transformed_value = osinfo_datamap_lookup(map, it->data);
+            if (transformed_value == NULL) {
+                continue;
+            }
+            it->data = (gpointer)transformed_value;
+        }
+    }
+
+    return values;
+}
+
+
+static xmlNodePtr osinfo_install_script_generate_entity_xml(OsinfoInstallScript *script,
+                                                            OsinfoEntity *entity,
+                                                            const gchar *name,
+                                                            GError **error)
 {
     xmlNodePtr node = NULL;
     xmlNodePtr data = NULL;
@@ -631,9 +688,17 @@ static xmlNodePtr osinfo_install_script_generate_entity_config(OsinfoInstallConf
 
     tmp1 = keys = osinfo_entity_get_param_keys(entity);
     while (tmp1) {
-        GList *values = osinfo_entity_get_param_value_list(entity, tmp1->data);
-        GList *tmp2 = values;
+        GList *values;
+        GList *tmp2;
 
+        if (OSINFO_IS_INSTALL_CONFIG(entity))
+            values = osinfo_install_script_get_param_value_list(script,
+                                                                OSINFO_INSTALL_CONFIG(entity),
+                                                                tmp1->data);
+        else
+            values = osinfo_entity_get_param_value_list(entity, tmp1->data);
+
+        tmp2 = values;
         while (tmp2) {
             if (!(data = xmlNewDocNode(NULL, NULL, (const xmlChar*)tmp1->data,
                                        (const xmlChar*)tmp2->data))) {
@@ -681,10 +746,10 @@ static xmlDocPtr osinfo_install_script_generate_config_xml(OsinfoInstallScript *
                          NULL);
     xmlDocSetRootElement(doc, root);
 
-    if (!(node = osinfo_install_script_generate_entity_config(config,
-                                                              OSINFO_ENTITY(script),
-                                                              "script",
-                                                              error)))
+    if (!(node = osinfo_install_script_generate_entity_xml(script,
+                                                           OSINFO_ENTITY(script),
+                                                           "script",
+                                                           error)))
         goto error;
     if (!(xmlAddChild(root, node))) {
         xmlErrorPtr err = xmlGetLastError();
@@ -692,10 +757,10 @@ static xmlDocPtr osinfo_install_script_generate_config_xml(OsinfoInstallScript *
         goto error;
     }
 
-    if (!(node = osinfo_install_script_generate_entity_config(config,
-                                                              OSINFO_ENTITY(os),
-                                                              "os",
-                                                              error)))
+    if (!(node = osinfo_install_script_generate_entity_xml(script,
+                                                           OSINFO_ENTITY(os),
+                                                           "os",
+                                                           error)))
         goto error;
     if (!(xmlAddChild(root, node))) {
         xmlErrorPtr err = xmlGetLastError();
@@ -703,10 +768,10 @@ static xmlDocPtr osinfo_install_script_generate_config_xml(OsinfoInstallScript *
         goto error;
     }
 
-    if (!(node = osinfo_install_script_generate_entity_config(config,
-                                                              OSINFO_ENTITY(config),
-                                                              "config",
-                                                              error)))
+    if (!(node = osinfo_install_script_generate_entity_xml(script,
+                                                           OSINFO_ENTITY(config),
+                                                           "config",
+                                                           error)))
         goto error;
     if (!(xmlAddChild(root, node))) {
         xmlErrorPtr err = xmlGetLastError();
@@ -727,7 +792,7 @@ static gchar *osinfo_install_script_apply_xslt(xsltStylesheetPtr ss,
                                                GError **error)
 {
     xsltTransformContextPtr ctxt;
-    gchar *ret;
+    gchar *ret = NULL;
     xmlDocPtr docOut = NULL;
     int len;
 
@@ -889,6 +954,14 @@ static gpointer osinfo_install_script_generate_finish_common(OsinfoInstallScript
     return g_simple_async_result_get_op_res_gpointer(simple);
 }
 
+/**
+ * osinfo_install_script_generate_finish:
+ * @script: the install script
+ * @res:    a #GAsyncResult
+ * @error:  The location where to store any error, or NULL
+ *
+ * Returns: (transfer full): the generated script, or NULL on error
+ */
 gchar *osinfo_install_script_generate_finish(OsinfoInstallScript *script,
                                              GAsyncResult *res,
                                              GError **error)
@@ -898,6 +971,14 @@ gchar *osinfo_install_script_generate_finish(OsinfoInstallScript *script,
                                                         error);
 }
 
+/**
+ * osinfo_install_script_generate_output_finish:
+ * @script: the install script
+ * @res:    a #GAsyncResult
+ * @error:  The location where to store any error, or NULL
+ *
+ * Returns: (transfer full): a file containing the script, or NULL on error
+ */
 GFile *osinfo_install_script_generate_output_finish(OsinfoInstallScript *script,
                                                     GAsyncResult *res,
                                                     GError **error)
@@ -1081,7 +1162,7 @@ void osinfo_install_script_generate_output_async(OsinfoInstallScript *script,
  * @cancellable: (allow-none): a #GCancellable, or %NULL
  * @error: The location where to store any error, or %NULL
  *
- * Creates a install script written in a file
+ * Creates an install script written in a file
  *
  * Returns: (transfer full): a file containing the script
  */
