@@ -133,9 +133,7 @@ osinfo_list_class_init (OsinfoListClass *klass)
                                OSINFO_TYPE_ENTITY,
                                G_PARAM_CONSTRUCT_ONLY |
                                G_PARAM_READWRITE |
-                               G_PARAM_STATIC_NAME |
-                               G_PARAM_STATIC_BLURB |
-                               G_PARAM_STATIC_NICK);
+                               G_PARAM_STATIC_STRINGS);
 
     g_object_class_install_property(g_klass,
                                     PROP_ELEMENT_TYPE,
@@ -450,8 +448,8 @@ OsinfoList *osinfo_list_new_filtered(OsinfoList *source, OsinfoFilter *filter)
  * @sourceOne: the first list to copy
  * @sourceTwo: the second list to copy
  *
- * Construct a new list that is filled with only the
- * s that are present in both @sourceOne and @sourceTwo.
+ * Construct a new list that is filled with only the elements
+ * that are present in both @sourceOne and @sourceTwo.
  *
  * Returns: (transfer full): an intersection of the two lists
  */
@@ -467,7 +465,7 @@ OsinfoList *osinfo_list_new_intersection(OsinfoList *sourceOne,
 }
 
 /**
- * osinfo_new_union:
+ * osinfo_list_new_union:
  * @sourceOne: the first list to copy
  * @sourceTwo: the second list to copy
  *
