@@ -287,6 +287,18 @@ static void osinfo_loader_entity(OsinfoLoader *loader,
     g_free(custom);
 }
 
+static OsinfoDatamap *osinfo_loader_get_datamap(OsinfoLoader *loader,
+                                                 const gchar *id)
+{
+    OsinfoDatamap *datamap = osinfo_db_get_datamap(loader->priv->db, id);
+    if (!datamap) {
+        datamap = osinfo_datamap_new(id);
+        osinfo_db_add_datamap(loader->priv->db, datamap);
+        g_object_unref(datamap);
+    }
+    return datamap;
+}
+
 static OsinfoDevice *osinfo_loader_get_device(OsinfoLoader *loader,
                                               const gchar *id)
 {
@@ -574,6 +586,46 @@ static void osinfo_loader_deployment(OsinfoLoader *loader,
     osinfo_db_add_deployment(loader->priv->db, deployment);
 }
 
+static void osinfo_loader_datamap(OsinfoLoader *loader,
+                                  xmlXPathContextPtr ctxt,
+                                  xmlNodePtr root,
+                                  GError **err)
+{
+    xmlNodePtr *nodes = NULL;
+    guint i;
+    int nnodes;
+
+    gchar *id = (gchar *)xmlGetProp(root, BAD_CAST "id");
+
+    if (!id) {
+        OSINFO_ERROR(err, _("Missing os id property"));
+        return;
+    }
+
+    OsinfoDatamap *map = osinfo_loader_get_datamap(loader, id);
+
+    nnodes = osinfo_loader_nodeset("./entry", ctxt, &nodes, err);
+    if (error_is_set(err))
+        goto cleanup;
+
+    for (i = 0 ; i < nnodes ; i++) {
+        gchar *inval = (gchar *)xmlGetProp(nodes[i], BAD_CAST "inval");
+        gchar *outval;
+
+        if (inval == NULL)
+            continue;
+        outval = (gchar *)xmlGetProp(nodes[i], BAD_CAST "outval");
+        osinfo_datamap_insert(map, inval, outval);
+
+        xmlFree(inval);
+        xmlFree(outval);
+    }
+
+cleanup:
+    g_free(nodes);
+    xmlFree(id);
+}
+
 static void osinfo_loader_install_config_params(OsinfoLoader *loader,
                                                 OsinfoEntity *entity,
                                                 const gchar *xpath,
@@ -590,12 +642,19 @@ static void osinfo_loader_install_config_params(OsinfoLoader *loader,
     for (i = 0 ; i < nnodes ; i++) {
         gchar *name = (gchar *)xmlGetProp(nodes[i], BAD_CAST OSINFO_INSTALL_CONFIG_PARAM_PROP_NAME);
         gchar *policy = (gchar *)xmlGetProp(nodes[i], BAD_CAST OSINFO_INSTALL_CONFIG_PARAM_PROP_POLICY);
+        gchar *mapid = (gchar *)xmlGetProp(nodes[i], BAD_CAST OSINFO_INSTALL_CONFIG_PARAM_PROP_DATAMAP);
         OsinfoInstallConfigParam *param = osinfo_install_config_param_new(name);
         osinfo_entity_set_param(OSINFO_ENTITY(param),
                                 OSINFO_INSTALL_CONFIG_PARAM_PROP_POLICY,
                                 policy);
         osinfo_install_script_add_config_param(OSINFO_INSTALL_SCRIPT(entity),
                                                param);
+        if (mapid != NULL) {
+            OsinfoDatamap *map;
+            map = osinfo_loader_get_datamap(loader, mapid);
+            if (map != NULL)
+                osinfo_install_config_param_set_value_map(param, map);
+        }
 
         xmlFree(name);
         xmlFree(policy);
@@ -777,12 +836,35 @@ static OsinfoMedia *osinfo_loader_media (OsinfoLoader *loader,
              strcmp((const gchar *)nodes[i]->name,
                     OSINFO_MEDIA_PROP_PUBLISHER_ID) != 0 &&
              strcmp((const gchar *)nodes[i]->name,
-                    OSINFO_MEDIA_PROP_APPLICATION_ID) != 0))
+                    OSINFO_MEDIA_PROP_APPLICATION_ID) != 0 &&
+             strcmp((const gchar *)nodes[i]->name,
+                    OSINFO_MEDIA_PROP_LANG) != 0))
             continue;
 
-        osinfo_entity_set_param(OSINFO_ENTITY(media),
-                                (const gchar *)nodes[i]->name,
-                                (const gchar *)nodes[i]->children->content);
+        if (strcmp((const gchar *)nodes[i]->name,
+                   OSINFO_MEDIA_PROP_LANG) == 0) {
+            gchar *regex = (gchar *)xmlGetProp(nodes[i], BAD_CAST "regex");
+            if (g_strcmp0(regex, "true") == 0) {
+                gchar *datamap;
+                osinfo_entity_set_param(OSINFO_ENTITY(media),
+                                        OSINFO_MEDIA_PROP_LANG_REGEX,
+                                        (const gchar *)nodes[i]->children->content);
+                datamap = (gchar *)xmlGetProp(nodes[i], BAD_CAST OSINFO_MEDIA_PROP_LANG_MAP);
+                if (datamap != NULL)
+                    osinfo_entity_set_param(OSINFO_ENTITY(media),
+                                            OSINFO_MEDIA_PROP_LANG_MAP,
+                                            datamap);
+            } else {
+                osinfo_entity_add_param(OSINFO_ENTITY(media),
+                                        OSINFO_MEDIA_PROP_LANG,
+                                        (const gchar *)nodes[i]->children->content);
+            }
+            xmlFree(regex);
+        } else {
+            osinfo_entity_set_param(OSINFO_ENTITY(media),
+                                    (const gchar *)nodes[i]->name,
+                                    (const gchar *)nodes[i]->children->content);
+        }
     }
 
     g_free(nodes);
@@ -825,22 +907,22 @@ static OsinfoTree *osinfo_loader_tree (OsinfoLoader *loader,
             continue;
 
         if (strcmp((const gchar *)nodes[i]->name,
-                   OSINFO_TREE_PROP_TREEINFO_FAMILY + 9) == 0)
+                   OSINFO_TREE_PROP_TREEINFO_FAMILY + sizeof("treeinfo-")) == 0)
             osinfo_entity_set_param(OSINFO_ENTITY(tree),
                                     OSINFO_TREE_PROP_TREEINFO_FAMILY,
                                     (const gchar *)nodes[i]->children->content);
         else if (strcmp((const gchar *)nodes[i]->name,
-                        OSINFO_TREE_PROP_TREEINFO_VARIANT + 9) == 0)
+                        OSINFO_TREE_PROP_TREEINFO_VARIANT + sizeof("treeinfo-")) == 0)
             osinfo_entity_set_param(OSINFO_ENTITY(tree),
                                     OSINFO_TREE_PROP_TREEINFO_VARIANT,
                                     (const gchar *)nodes[i]->children->content);
         else if (strcmp((const gchar *)nodes[i]->name,
-                        OSINFO_TREE_PROP_TREEINFO_VERSION + 9) == 0)
+                        OSINFO_TREE_PROP_TREEINFO_VERSION + sizeof("treeinfo-")) == 0)
             osinfo_entity_set_param(OSINFO_ENTITY(tree),
                                     OSINFO_TREE_PROP_TREEINFO_VERSION,
                                     (const gchar *)nodes[i]->children->content);
         else if (strcmp((const gchar *)nodes[i]->name,
-                        OSINFO_TREE_PROP_TREEINFO_ARCH + 9) == 0)
+                        OSINFO_TREE_PROP_TREEINFO_ARCH + sizeof("treeinfo-")) == 0)
             osinfo_entity_set_param(OSINFO_ENTITY(tree),
                                     OSINFO_TREE_PROP_TREEINFO_ARCH,
                                     (const gchar *)nodes[i]->children->content);
@@ -1150,7 +1232,7 @@ static void osinfo_loader_root(OsinfoLoader *loader,
      *   If closing libosinfo tag, break
      *   If non element tag, continue
      *   If element tag, and element is not os, platform, device,
-     *   deployment or install-script, error
+     *   datamap, deployment or install-script, error
      *   Else, switch on tag type and handle reading in data
      * After loop, return success if no error
      * If there was an error, clean up lib data acquired so far
@@ -1160,12 +1242,14 @@ static void osinfo_loader_root(OsinfoLoader *loader,
     xmlNodePtr *platforms = NULL;
     xmlNodePtr *deployments = NULL;
     xmlNodePtr *installScripts = NULL;
+    xmlNodePtr *dataMaps = NULL;
     int i;
     int ndeployment;
     int nos;
     int ndevice;
     int nplatform;
     int ninstallScript;
+    int ndataMaps;
 
     if (!xmlStrEqual(root->name, BAD_CAST "libosinfo")) {
         OSINFO_ERROR(err, _("Incorrect root element"));
@@ -1237,8 +1321,21 @@ static void osinfo_loader_root(OsinfoLoader *loader,
             goto cleanup;
     }
 
+    ndataMaps = osinfo_loader_nodeset("./datamap", ctxt, &dataMaps, err);
+    if (error_is_set(err))
+        goto cleanup;
+
+    for (i = 0 ; i < ndataMaps ; i++) {
+        xmlNodePtr saved = ctxt->node;
+        ctxt->node = dataMaps[i];
+        osinfo_loader_datamap(loader, ctxt, dataMaps[i], err);
+        ctxt->node = saved;
+        if (error_is_set(err))
+            goto cleanup;
+    }
 
  cleanup:
+    g_free(dataMaps);
     g_free(installScripts);
     g_free(deployments);
     g_free(platforms);
