@@ -25,6 +25,7 @@
 #include <config.h>
 
 #include <osinfo/osinfo.h>
+#include "osinfo_media_private.h"
 #include <glib/gi18n-lib.h>
 
 G_DEFINE_TYPE (OsinfoOs, osinfo_os, OSINFO_TYPE_PRODUCT);
@@ -145,9 +146,7 @@ osinfo_os_class_init (OsinfoOsClass *klass)
                                  _("Generic Family"),
                                  NULL /* default value */,
                                  G_PARAM_READABLE |
-                                 G_PARAM_STATIC_NAME |
-                                 G_PARAM_STATIC_NICK |
-                                 G_PARAM_STATIC_BLURB);
+                                 G_PARAM_STATIC_STRINGS);
     g_object_class_install_property (g_klass,
                                      PROP_FAMILY,
                                      pspec);
@@ -163,9 +162,7 @@ osinfo_os_class_init (OsinfoOsClass *klass)
                                  _("Generic Distro"),
                                  NULL /* default value */,
                                  G_PARAM_READABLE |
-                                 G_PARAM_STATIC_NAME |
-                                 G_PARAM_STATIC_NICK |
-                                 G_PARAM_STATIC_BLURB);
+                                 G_PARAM_STATIC_STRINGS);
     g_object_class_install_property (g_klass,
                                      PROP_DISTRO,
                                      pspec);
@@ -371,7 +368,7 @@ OsinfoDeviceLink *osinfo_os_add_device(OsinfoOs *os, OsinfoDevice *dev)
 
 /**
  * osinfo_os_get_family:
- * @os: a OsinfoOs
+ * @os: an #OsinfoOs
  *
  * Retrieves the generic family the OS @os belongs to, based upon its kernel,
  * for example linux, winnt, solaris, freebsd etc.
@@ -387,7 +384,7 @@ const gchar *osinfo_os_get_family(OsinfoOs *os)
 
 /**
  * osinfo_os_get_distro:
- * @os: a OsinfoOs
+ * @os: an #OsinfoOs
  *
  * Retrieves the generic family the OS @os belongs to, for example fedora,
  * ubuntu, windows, solaris, freebsd etc.
@@ -433,6 +430,7 @@ void osinfo_os_add_media(OsinfoOs *os, OsinfoMedia *media)
     g_return_if_fail(OSINFO_IS_MEDIA(media));
 
     osinfo_list_add(OSINFO_LIST(os->priv->medias), OSINFO_ENTITY(media));
+    osinfo_media_set_os(media, os);
 }
 
 /**
@@ -540,7 +538,13 @@ void osinfo_os_add_recommended_resources(OsinfoOs *os,
                     OSINFO_ENTITY(resources));
 }
 
-
+/**
+ * osinfo_os_find_install_script:
+ * @os:      an operating system
+ * @profile: the install script profile
+ *
+ * Returns: (transfer full): A new #OsinfoInstallScript for the @os @profile
+ */
 OsinfoInstallScript *osinfo_os_find_install_script(OsinfoOs *os, const gchar *profile)
 {
     g_return_val_if_fail(OSINFO_IS_OS(os), NULL);
