@@ -132,6 +132,8 @@ osinfo_product_get_property (GObject    *object,
     case PROP_CODENAME:
         g_value_set_string (value,
                             osinfo_product_get_codename (product));
+        break;
+
     case PROP_LOGO:
         g_value_set_string (value,
                             osinfo_product_get_logo (product));
@@ -156,7 +158,7 @@ osinfo_product_class_init (OsinfoProductClass *klass)
     g_type_class_add_private (klass, sizeof (OsinfoProductPrivate));
 
     /**
-     * OsinfoProduct::name:
+     * OsinfoProduct:name:
      *
      * The name of this product.
      */
@@ -165,13 +167,11 @@ osinfo_product_class_init (OsinfoProductClass *klass)
                                  _("Name"),
                                  NULL /* default value */,
                                  G_PARAM_READABLE |
-                                 G_PARAM_STATIC_NAME |
-                                 G_PARAM_STATIC_NICK |
-                                 G_PARAM_STATIC_BLURB);
+                                 G_PARAM_STATIC_STRINGS);
     g_object_class_install_property (g_klass, PROP_NAME, pspec);
 
     /**
-     * OsinfoProduct::short-id:
+     * OsinfoProduct:short-id:
      *
      * The short ID of this product.
      */
@@ -180,13 +180,11 @@ osinfo_product_class_init (OsinfoProductClass *klass)
                                  _("Short ID"),
                                  NULL /* default value */,
                                  G_PARAM_READABLE |
-                                 G_PARAM_STATIC_NAME |
-                                 G_PARAM_STATIC_NICK |
-                                 G_PARAM_STATIC_BLURB);
+                                 G_PARAM_STATIC_STRINGS);
     g_object_class_install_property (g_klass, PROP_SHORT_ID, pspec);
 
     /**
-     * OsinfoProduct::vendor:
+     * OsinfoProduct:vendor:
      *
      * The Vendor of this product.
      */
@@ -195,13 +193,11 @@ osinfo_product_class_init (OsinfoProductClass *klass)
                                  _("Vendor"),
                                  NULL /* default value */,
                                  G_PARAM_READABLE |
-                                 G_PARAM_STATIC_NAME |
-                                 G_PARAM_STATIC_NICK |
-                                 G_PARAM_STATIC_BLURB);
+                                 G_PARAM_STATIC_STRINGS);
     g_object_class_install_property (g_klass, PROP_VENDOR, pspec);
 
     /**
-     * OsinfoProduct::version:
+     * OsinfoProduct:version:
      *
      * The version of the product.
      */
@@ -210,13 +206,11 @@ osinfo_product_class_init (OsinfoProductClass *klass)
                                  _("Version"),
                                  NULL /* default value */,
                                  G_PARAM_READABLE |
-                                 G_PARAM_STATIC_NAME |
-                                 G_PARAM_STATIC_NICK |
-                                 G_PARAM_STATIC_BLURB);
+                                 G_PARAM_STATIC_STRINGS);
     g_object_class_install_property (g_klass, PROP_VERSION, pspec);
 
     /**
-     * OsinfoProduct::codename:
+     * OsinfoProduct:codename:
      *
      * The codename of this product.
      */
@@ -225,13 +219,11 @@ osinfo_product_class_init (OsinfoProductClass *klass)
                                  _("Codename"),
                                  NULL /* default value */,
                                  G_PARAM_READABLE |
-                                 G_PARAM_STATIC_NAME |
-                                 G_PARAM_STATIC_NICK |
-                                 G_PARAM_STATIC_BLURB);
+                                 G_PARAM_STATIC_STRINGS);
     g_object_class_install_property (g_klass, PROP_NAME, pspec);
 
     /**
-     * OsinfoProduct::logo:
+     * OsinfoProduct:logo:
      *
      * The URI of the logo of the product.
      */
@@ -240,9 +232,7 @@ osinfo_product_class_init (OsinfoProductClass *klass)
                                  _("URI of the logo"),
                                  NULL /* default value */,
                                  G_PARAM_READABLE |
-                                 G_PARAM_STATIC_NAME |
-                                 G_PARAM_STATIC_NICK |
-                                 G_PARAM_STATIC_BLURB);
+                                 G_PARAM_STATIC_STRINGS);
     g_object_class_install_property (g_klass, PROP_LOGO, pspec);
 }
 
