@@ -25,6 +25,7 @@
 #include <config.h>
 
 #include <osinfo/osinfo.h>
+#include <glib/gi18n-lib.h>
 
 G_DEFINE_TYPE (OsinfoProductList, osinfo_productlist, OSINFO_TYPE_LIST);
 
@@ -93,6 +94,7 @@ OsinfoProductList *osinfo_productlist_new(void)
  * from @source
  *
  * Returns: (transfer full): a copy of the os list
+ * Deprecated: 0.2.2: Use osinfo_list_new_copy() instead.
  */
 OsinfoProductList *osinfo_productlist_new_copy(OsinfoProductList *source)
 {
@@ -111,6 +113,7 @@ OsinfoProductList *osinfo_productlist_new_copy(OsinfoProductList *source)
  * from @source that match @filter
  *
  * Returns: (transfer full): a filtered copy of the os list
+ * Deprecated: 0.2.2: Use osinfo_list_new_filtered() instead.
  */
 OsinfoProductList *osinfo_productlist_new_filtered(OsinfoProductList *source, OsinfoFilter *filter)
 {
@@ -130,6 +133,7 @@ OsinfoProductList *osinfo_productlist_new_filtered(OsinfoProductList *source, Os
  * oss that are present in both @sourceOne and @sourceTwo.
  *
  * Returns: (transfer full): an intersection of the two os lists
+ * Deprecated: 0.2.2: Use osinfo_list_new_intersection() instead.
  */
 OsinfoProductList *osinfo_productlist_new_intersection(OsinfoProductList *sourceOne, OsinfoProductList *sourceTwo)
 {
@@ -149,6 +153,7 @@ OsinfoProductList *osinfo_productlist_new_intersection(OsinfoProductList *source
  * oss that are present in either @sourceOne and @sourceTwo.
  *
  * Returns: (transfer full): a union of the two os lists
+ * Deprecated: 0.2.2: Use osinfo_list_new_union() instead.
  */
 OsinfoProductList *osinfo_productlist_new_union(OsinfoProductList *sourceOne, OsinfoProductList *sourceTwo)
 {
