@@ -268,7 +268,7 @@ osinfo_tree_class_init(OsinfoTreeClass *klass)
     g_type_class_add_private(klass, sizeof(OsinfoTreePrivate));
 
     /**
-     * OsinfoTree::architecture:
+     * OsinfoTree:architecture:
      *
      * The target hardware architecture of this tree.
      */
@@ -277,13 +277,11 @@ osinfo_tree_class_init(OsinfoTreeClass *klass)
                                 _("CPU Architecture"),
                                 NULL /* default value */,
                                 G_PARAM_READWRITE |
-                                G_PARAM_STATIC_NAME |
-                                G_PARAM_STATIC_NICK |
-                                G_PARAM_STATIC_BLURB);
+                                G_PARAM_STATIC_STRINGS);
     g_object_class_install_property(g_klass, PROP_ARCHITECTURE, pspec);
 
     /**
-     * OsinfoTree::url:
+     * OsinfoTree:url:
      *
      * The URL to this tree.
      */
@@ -292,13 +290,11 @@ osinfo_tree_class_init(OsinfoTreeClass *klass)
                                 _("The URL to this tree"),
                                 NULL /* default value */,
                                 G_PARAM_READWRITE |
-                                G_PARAM_STATIC_NAME |
-                                G_PARAM_STATIC_NICK |
-                                G_PARAM_STATIC_BLURB);
+                                G_PARAM_STATIC_STRINGS);
     g_object_class_install_property(g_klass, PROP_URL, pspec);
 
     /**
-     * OsinfoTree::volume-id:
+     * OsinfoTree:volume-id:
      *
      * Expected volume ID (regular expression) for ISO9660 image/device.
      */
@@ -307,13 +303,11 @@ osinfo_tree_class_init(OsinfoTreeClass *klass)
                                 _("The expected ISO9660 volume ID"),
                                 NULL /* default value */,
                                 G_PARAM_READWRITE |
-                                G_PARAM_STATIC_NAME |
-                                G_PARAM_STATIC_NICK |
-                                G_PARAM_STATIC_BLURB);
+                                G_PARAM_STATIC_STRINGS);
     g_object_class_install_property(g_klass, PROP_TREEINFO_FAMILY, pspec);
 
     /**
-     * OsinfoTree::publisher-id:
+     * OsinfoTree:publisher-id:
      *
      * Expected publisher ID (regular expression) for ISO9660 image/device.
      */
@@ -322,13 +316,11 @@ osinfo_tree_class_init(OsinfoTreeClass *klass)
                                 _("The expected ISO9660 publisher ID"),
                                 NULL /* default value */,
                                 G_PARAM_READWRITE |
-                                G_PARAM_STATIC_NAME |
-                                G_PARAM_STATIC_NICK |
-                                G_PARAM_STATIC_BLURB);
+                                G_PARAM_STATIC_STRINGS);
     g_object_class_install_property(g_klass, PROP_TREEINFO_VARIANT, pspec);
 
     /**
-     * OsinfoTree::application-id:
+     * OsinfoTree:application-id:
      *
      * Expected application ID (regular expression) for ISO9660 image/device.
      */
@@ -337,13 +329,11 @@ osinfo_tree_class_init(OsinfoTreeClass *klass)
                                 _("The expected ISO9660 application ID"),
                                 NULL /* default value */,
                                 G_PARAM_READWRITE |
-                                G_PARAM_STATIC_NAME |
-                                G_PARAM_STATIC_NICK |
-                                G_PARAM_STATIC_BLURB);
+                                G_PARAM_STATIC_STRINGS);
     g_object_class_install_property(g_klass, PROP_TREEINFO_VERSION, pspec);
 
     /**
-     * OsinfoTree::system-id:
+     * OsinfoTree:system-id:
      *
      * Expected system ID (regular expression) for ISO9660 image/device.
      */
@@ -352,13 +342,11 @@ osinfo_tree_class_init(OsinfoTreeClass *klass)
                                 _("The expected ISO9660 system ID"),
                                 NULL /* default value */,
                                 G_PARAM_READWRITE |
-                                G_PARAM_STATIC_NAME |
-                                G_PARAM_STATIC_NICK |
-                                G_PARAM_STATIC_BLURB);
+                                G_PARAM_STATIC_STRINGS);
     g_object_class_install_property(g_klass, PROP_TREEINFO_ARCH, pspec);
 
     /**
-     * OsinfoTree::kernel-path:
+     * OsinfoTree:kernel-path:
      *
      * The path to the kernel image in the install tree.
      */
@@ -367,13 +355,11 @@ osinfo_tree_class_init(OsinfoTreeClass *klass)
                                 _("The path to the kernel image"),
                                 NULL /* default value */,
                                 G_PARAM_READWRITE |
-                                G_PARAM_STATIC_NAME |
-                                G_PARAM_STATIC_NICK |
-                                G_PARAM_STATIC_BLURB);
+                                G_PARAM_STATIC_STRINGS);
     g_object_class_install_property(g_klass, PROP_KERNEL_PATH, pspec);
 
     /**
-     * OsinfoTree::initrd-path:
+     * OsinfoTree:initrd-path:
      *
      * The path to the initrd image in the install tree.
      */
@@ -382,13 +368,11 @@ osinfo_tree_class_init(OsinfoTreeClass *klass)
                                 _("The path to the inirtd image"),
                                 NULL /* default value */,
                                 G_PARAM_READWRITE |
-                                G_PARAM_STATIC_NAME |
-                                G_PARAM_STATIC_NICK |
-                                G_PARAM_STATIC_BLURB);
+                                G_PARAM_STATIC_STRINGS);
     g_object_class_install_property(g_klass, PROP_INITRD_PATH, pspec);
 
     /**
-     * OsinfoTree::boot-iso-path:
+     * OsinfoTree:boot-iso-path:
      *
      * The path to the boot ISO in the install tree
      */
@@ -397,9 +381,7 @@ osinfo_tree_class_init(OsinfoTreeClass *klass)
                                 _("The path to the bootable ISO image"),
                                 NULL /* default value */,
                                 G_PARAM_READWRITE |
-                                G_PARAM_STATIC_NAME |
-                                G_PARAM_STATIC_NICK |
-                                G_PARAM_STATIC_BLURB);
+                                G_PARAM_STATIC_STRINGS);
     g_object_class_install_property(g_klass, PROP_BOOT_ISO_PATH, pspec);
 
 }
@@ -716,7 +698,7 @@ OsinfoTree *osinfo_tree_create_from_location_finish(GAsyncResult *res,
 
 /**
  * osinfo_tree_get_architecture:
- * @tree: a #OsinfoTree instance
+ * @tree: an #OsinfoTree instance
  *
  * Retrieves the target hardware architecture of the OS @tree provides.
  *
@@ -730,7 +712,7 @@ const gchar *osinfo_tree_get_architecture(OsinfoTree *tree)
 
 /**
  * osinfo_tree_get_url:
- * @tree: a #OsinfoTree instance
+ * @tree: an #OsinfoTree instance
  *
  * The URL to the @tree
  *
@@ -744,7 +726,7 @@ const gchar *osinfo_tree_get_url(OsinfoTree *tree)
 
 /**
  * osinfo_tree_get_treeinfo_family:
- * @tree: a #OsinfoTree instance
+ * @tree: an #OsinfoTree instance
  *
  * If @tree is an ISO9660 image/device, this function retrieves the expected
  * volume ID.
@@ -763,7 +745,7 @@ const gchar *osinfo_tree_get_treeinfo_family(OsinfoTree *tree)
 
 /**
  * osinfo_tree_get_treeinfo_arch:
- * @tree: a #OsinfoTree instance
+ * @tree: an #OsinfoTree instance
  *
  * If @tree is an ISO9660 image/device, this function retrieves the expected
  * system ID.
@@ -782,7 +764,7 @@ const gchar *osinfo_tree_get_treeinfo_arch(OsinfoTree *tree)
 
 /**
  * osinfo_tree_get_treeinfo_variant:
- * @tree: a #OsinfoTree instance
+ * @tree: an #OsinfoTree instance
  *
  * If @tree is an ISO9660 image/device, this function retrieves the expected
  * publisher ID.
@@ -801,7 +783,7 @@ const gchar *osinfo_tree_get_treeinfo_variant(OsinfoTree *tree)
 
 /**
  * osinfo_tree_get_treeinfo_version:
- * @tree: a #OsinfoTree instance
+ * @tree: an #OsinfoTree instance
  *
  * If @tree is an ISO9660 image/device, this function retrieves the expected
  * application ID.
@@ -820,7 +802,7 @@ const gchar *osinfo_tree_get_treeinfo_version(OsinfoTree *tree)
 
 /**
  * osinfo_tree_get_boot_iso_path:
- * @tree: a #OsinfoTree instance
+ * @tree: an #OsinfoTree instance
  *
  * Retrieves the path to the boot_iso image in the install tree.
  *
@@ -834,7 +816,7 @@ const gchar *osinfo_tree_get_boot_iso_path(OsinfoTree *tree)
 
 /**
  * osinfo_tree_get_kernel_path:
- * @tree: a #OsinfoTree instance
+ * @tree: an #OsinfoTree instance
  *
  * Retrieves the path to the kernel image in the install tree.
  *
@@ -850,7 +832,7 @@ const gchar *osinfo_tree_get_kernel_path(OsinfoTree *tree)
 
 /**
  * osinfo_tree_get_initrd_path:
- * @tree: a #OsinfoTree instance
+ * @tree: an #OsinfoTree instance
  *
  * Retrieves the path to the initrd image in the install tree.
  *
